==> pegasus-merchandise-api-4.0.6-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpChannelCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpChannelCond.java, v 0.1 2015-07-31 11:40
 */
public class OpChannelCond extends BaseQueryCond {
    /**
     * 渠道编码
     */
    private String code;

    private String notCode;

    private List<String> codes;

    private List<String> notInCodes;
    /**
     * 渠道名
     */
    private String name;
    private String nameLike;
    /**
     * 渠道类型，1线下2线上
     */
    private Integer channelType;
    /**
     * 销售仓
     */
    private String warehouseForSales;
    /**
     * 创建时间
     */
    private Date createTime;
    private String createTimeStart;
    private String createTimeEnd;

    // 所属平台
    private Integer wayType;
    private List<Integer> wayTypes;

    // 业务线
    private Integer serviceLine;

    private List<Integer> serviceLines;

    private boolean fetchServiceLineFlag;

    private String orderByClause;

    private Integer channelStatus;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public List<String> getCodes() {
        return codes;
    }

    public void setCodes(List<String> codes) {
        this.codes = codes;
    }

    public String getNotCode() {
        return notCode;
    }

    public void setNotCode(String notCode) {
        this.notCode = notCode;
    }

    public List<String> getNotInCodes() {
        return notInCodes;
    }

    public void setNotInCodes(List<String> notInCodes) {
        this.notInCodes = notInCodes;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameLike() {
        return nameLike;
    }

    public void setNameLike(String nameLike) {
        this.nameLike = nameLike;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public String getWarehouseForSales() {
        return warehouseForSales;
    }

    public void setWarehouseForSales(String warehouseForSales) {
        this.warehouseForSales = warehouseForSales;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(String createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public String getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(String createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }

    public Integer getWayType() {
        return wayType;
    }

    public void setWayType(Integer wayType) {
        this.wayType = wayType;
    }

    public List<Integer> getWayTypes() {
        return wayTypes;
    }

    public void setWayTypes(List<Integer> wayTypes) {
        this.wayTypes = wayTypes;
    }

    public Integer getServiceLine() {
        return serviceLine;
    }

    public void setServiceLine(Integer serviceLine) {
        this.serviceLine = serviceLine;
    }

    public List<Integer> getServiceLines() {
        return serviceLines;
    }

    public void setServiceLines(List<Integer> serviceLines) {
        this.serviceLines = serviceLines;
    }

    public boolean isFetchServiceLineFlag() {
        return fetchServiceLineFlag;
    }

    public void setFetchServiceLineFlag(boolean fetchServiceLineFlag) {
        this.fetchServiceLineFlag = fetchServiceLineFlag;
    }

    public String getOrderByClause() {
        return orderByClause;
    }

    public void setOrderByClause(String orderByClause) {
        this.orderByClause = orderByClause;
    }

    public Integer getChannelStatus() {
        return channelStatus;
    }

    public void setChannelStatus(Integer channelStatus) {
        this.channelStatus = channelStatus;
    }
}

==> pegasus-merchandise-api-1009628-20251212.094020-1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpChannelCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpChannelCond.java, v 0.1 2015-07-31 11:40
 */
public class OpChannelCond extends BaseQueryCond {
    /**
     * 渠道编码
     */
    private String code;

    private String notCode;

    private List<String> codes;

    private List<String> notInCodes;
    /**
     * 渠道名
     */
    private String name;
    private String nameLike;
    /**
     * 渠道类型，1线下2线上
     */
    private Integer channelType;
    /**
     * 销售仓
     */
    private String warehouseForSales;
    /**
     * 创建时间
     */
    private Date createTime;
    private String createTimeStart;
    private String createTimeEnd;

    // 所属平台
    private Integer wayType;
    private List<Integer> wayTypes;

    // 业务线
    private Integer serviceLine;

    private List<Integer> serviceLines;

    private boolean fetchServiceLineFlag;

    private String orderByClause;

    private Integer channelStatus;
    private String storeId;
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public List<String> getCodes() {
        return codes;
    }

    public void setCodes(List<String> codes) {
        this.codes = codes;
    }

    public String getNotCode() {
        return notCode;
    }

    public void setNotCode(String notCode) {
        this.notCode = notCode;
    }

    public List<String> getNotInCodes() {
        return notInCodes;
    }

    public String getStoreId() {
        return storeId;
    }

    public void setStoreId(String storeId) {
        this.storeId = storeId;
    }

    public void setNotInCodes(List<String> notInCodes) {
        this.notInCodes = notInCodes;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getNameLike() {
        return nameLike;
    }

    public void setNameLike(String nameLike) {
        this.nameLike = nameLike;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public String getWarehouseForSales() {
        return warehouseForSales;
    }

    public void setWarehouseForSales(String warehouseForSales) {
        this.warehouseForSales = warehouseForSales;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(String createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public String getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(String createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }

    public Integer getWayType() {
        return wayType;
    }

    public void setWayType(Integer wayType) {
        this.wayType = wayType;
    }

    public List<Integer> getWayTypes() {
        return wayTypes;
    }

    public void setWayTypes(List<Integer> wayTypes) {
        this.wayTypes = wayTypes;
    }

    public Integer getServiceLine() {
        return serviceLine;
    }

    public void setServiceLine(Integer serviceLine) {
        this.serviceLine = serviceLine;
    }

    public List<Integer> getServiceLines() {
        return serviceLines;
    }

    public void setServiceLines(List<Integer> serviceLines) {
        this.serviceLines = serviceLines;
    }

    public boolean isFetchServiceLineFlag() {
        return fetchServiceLineFlag;
    }

    public void setFetchServiceLineFlag(boolean fetchServiceLineFlag) {
        this.fetchServiceLineFlag = fetchServiceLineFlag;
    }

    public String getOrderByClause() {
        return orderByClause;
    }

    public void setOrderByClause(String orderByClause) {
        this.orderByClause = orderByClause;
    }

    public Integer getChannelStatus() {
        return channelStatus;
    }

    public void setChannelStatus(Integer channelStatus) {
        this.channelStatus = channelStatus;
    }
}
